@@ -1198,7 +1198,14 @@ static void goto_label()
 {
 	char label_name[31];
 
-	strcpy(label_name,*tokp);
+/*  is there a label to go to? */
+	if (*tokp == NULL) {
+		printf("LABEL TO 'GOTO' NOT INCLUDED ON COMMAND LINE\n");
+		LONGJMP(reset, 1);
+		}
+	else {
+		strcpy(label_name,*tokp);
+		}
 
 	/* is a file open */
 	if  (!batfp) {
